==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-kogito-apps/data-index/data-index-storage/data-index-storage-api/src/main/java/org/kie/kogito/index/storage/DataIndexStorageService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.kogito.index.storage;

import org.kie.kogito.index.model.Job;
import org.kie.kogito.index.model.ProcessDefinition;
import org.kie.kogito.index.model.ProcessDefinitionKey;
import org.kie.kogito.persistence.api.Storage;

import com.fasterxml.jackson.databind.node.ObjectNode;

public interface DataIndexStorageService {

    Storage<ProcessDefinitionKey, ProcessDefinition> getProcessDefinitionStorage();

    ProcessInstanceStorage getProcessInstanceStorage();

    UserTaskInstanceStorage getUserTaskInstanceStorage();

    Storage<String, Job> getJobsStorage();

    Storage<String, ObjectNode> getDomainModelCache(String processId);

    String getDomainModelCacheName(String processId);

    Storage<String, String> getProcessIdModelCache();
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-kogito-apps/data-index/data-index-storage/data-index-storage-api/src/main/java/org/kie/kogito/index/storage/DataIndexStorageService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.kie.kogito.index.storage;

import java.util.EnumSet;
import java.util.Set;

import org.kie.kogito.index.model.Job;
import org.kie.kogito.index.model.ProcessDefinition;
import org.kie.kogito.index.model.ProcessDefinitionKey;
import org.kie.kogito.persistence.api.Storage;
import org.kie.kogito.persistence.api.StorageServiceCapability;

import com.fasterxml.jackson.databind.node.ObjectNode;

public interface DataIndexStorageService {
    Storage<ProcessDefinitionKey, ProcessDefinition> getProcessDefinitionStorage();

    ProcessInstanceStorage getProcessInstanceStorage();

    UserTaskInstanceStorage getUserTaskInstanceStorage();

    Storage<String, Job> getJobsStorage();

    Storage<String, ObjectNode> getDomainModelCache(String processId);

    String getDomainModelCacheName(String processId);

    Storage<String, String> getProcessIdModelCache();

    default Set<StorageServiceCapability> capabilities() {
        return EnumSet.noneOf(StorageServiceCapability.class);
    }
}
